@@ -1,11 +1,11 @@
-# Copyright (C) 2020-2021 Markus Wallerberger and others
+# Copyright (C) 2020-2022 Markus Wallerberger, Hiroshi Shinaoka, and others
 # SPDX-License-Identifier: MIT
 import numpy as np
 from warnings import warn
 from typing import Callable
 
 
-class KernelBase:
+class AbstractKernel:
     """Integral kernel ``K(x, y)``.
 
     Abstract base class for an integral kernel, i.e., a real binary function
@@ -42,7 +42,7 @@ class KernelBase:
         Advises the SVE routines of discretisation parameters suitable in
         tranforming the (infinite) SVE into an (finite) SVD problem.
 
-        See: :class:``SVEHintsBase``.
+        See: :class:``AbstractSVEHints``.
         """
         raise NotImplementedError()
 
@@ -71,8 +71,8 @@ class KernelBase:
         """Return symmetrized kernel ``K(x, y) + sign * K(x, -y)``.
 
         By default, this returns a simple wrapper over the current instance
-        which naively performs the sum.  You may want to override if this
-        to avoid cancellation.
+        which naively performs the sum.  You may want to override this to
+        avoid cancellation.
         """
         return ReducedKernel(self, sign)
 
@@ -99,7 +99,7 @@ class KernelBase:
         return lambda x: np.ones_like(x)
 
 
-class SVEHintsBase:
+class AbstractSVEHints:
     """Discretization hints for singular value expansion of a given kernel."""
     @property
     def segments_x(self):
@@ -113,7 +113,7 @@ class SVEHintsBase:
 
     @property
     def segments_y(self):
-        """Segments for piecewise polynomials on the ``x`` axis.
+        """Segments for piecewise polynomials on the ``y`` axis.
 
         List of segments on the ``y`` axis for the associated piecewise
         polynomial.  Should reflect the approximate position of roots of a
@@ -131,12 +131,12 @@ class SVEHintsBase:
         """Upper bound for number of singular values
 
         Upper bound on the number of singular values above the given
-        threshold, i.e., where ``s[l] >= eps * s[0]```
+        threshold, i.e., where ``s[l] >= eps * s[0]``.
         """
         raise NotImplementedError()
 
 
-class LogisticKernel(KernelBase):
+class LogisticKernel(AbstractKernel):
     """Fermionic/bosonic analytical continuation kernel.
 
     In dimensionless variables ``x = 2*τ/β - 1``, ``y = β*ω/Λ``,
@@ -147,11 +147,16 @@ class LogisticKernel(KernelBase):
     LogisticKernel is a fermionic analytic continuation kernel.
     Nevertheless, one can model the τ dependence of
     a bosonic correlation function as follows:
+
         ∫ exp(-Λ * y * (x + 1)/2) / (1 - exp(-Λ*y)) ρ(y) dy
         = ∫ K(x, y) ρ'(y) dy,
+
     with
+
         ρ'(y) == w(y) * ρ(y),
+
     where the weight function is given by
+
         w(y) = 1/tanh(Λ*y/2).
     """
     def __init__(self, lambda_):
@@ -203,10 +208,10 @@ class LogisticKernel(KernelBase):
         if statistics == "F":
             return lambda y: np.ones_like(y)
         else:
-            return lambda y: 1/np.tanh(0.5*y)
+            return lambda y: 1/np.tanh(0.5*self.lambda_*y)
 
 
-class _SVEHintsLogistic(SVEHintsBase):
+class _SVEHintsLogistic(AbstractSVEHints):
     def __init__(self, kernel, eps):
         self.kernel = kernel
         self.eps = eps
@@ -246,7 +251,7 @@ class _SVEHintsLogistic(SVEHintsBase):
         return int(np.round((25 + log10_lambda) * log10_lambda))
 
 
-class RegularizedBoseKernel(KernelBase):
+class RegularizedBoseKernel(AbstractKernel):
     """Regularized bosonic analytical continuation kernel.
 
     In dimensionless variables ``x = 2*τ/β - 1``, ``y = β*ω/Λ``, the fermionic
@@ -281,7 +286,7 @@ class RegularizedBoseKernel(KernelBase):
         # separately.  Secondly, the denominator loses precision around 0 since
         # exp(v) = 1 + v + ..., which can be avoided using expm1(...)
         not_tiny = abs_v >= 1e-200
-        denom = np.ones_like(abs_v)
+        denom = -np.ones_like(abs_v)
         np.divide(abs_v, np.expm1(-abs_v, where=not_tiny),
                   out=denom, where=not_tiny)
         return -1/dtype.type(self.lambda_) * enum * denom
@@ -311,7 +316,7 @@ class RegularizedBoseKernel(KernelBase):
         return lambda y: 1/y
 
 
-class _SVEHintsRegularizedBose(SVEHintsBase):
+class _SVEHintsRegularizedBose(AbstractSVEHints):
     def __init__(self, kernel, eps):
         self.kernel = kernel
         self.eps = eps
@@ -322,7 +327,7 @@ class _SVEHintsRegularizedBose(SVEHintsBase):
     @property
     def segments_x(self):
         # Somewhat less accurate ...
-        nzeros = 15 * np.log10(self.kernel.lambda_)
+        nzeros = max(int(np.round(15 * np.log10(self.kernel.lambda_))), 15)
         diffs = 1./np.cosh(.18 * np.arange(nzeros))
         zeros_pos = diffs.cumsum()
         zeros_pos /= zeros_pos[-1]
@@ -351,10 +356,10 @@ class _SVEHintsRegularizedBose(SVEHintsBase):
         return int(28 * log10_lambda)
 
 
-class ReducedKernel(KernelBase):
+class ReducedKernel(AbstractKernel):
     """Restriction of centrosymmetric kernel to positive interval.
 
-    For a kernel ``K`` on ``[-1, 1] x [-1, 1]`` that is centrosymmetrix, i.e.,
+    For a kernel ``K`` on ``[-1, 1] x [-1, 1]`` that is centrosymmetric, i.e.
     ``K(x, y) == K(-x, -y)``, it is straight-forward to show that the left/right
     singular vectors can be chosen as either odd or even functions.
 
@@ -416,7 +421,7 @@ class ReducedKernel(KernelBase):
     def conv_radius(self): return self.inner.conv_radius
 
 
-class _SVEHintsReduced(SVEHintsBase):
+class _SVEHintsReduced(AbstractSVEHints):
     def __init__(self, inner_hints):
         self.inner_hints = inner_hints
 
