@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: MIT
 import numpy as np
 
-from . import kernel
+from .kernel import LogisticKernel
 from . import sampling
 from . import basis as _basis
 from . import _util
@@ -10,19 +10,24 @@ from . import svd
 
 
 class MatsubaraPoleBasis:
-    def __init__(self, beta, poles):
-        self._beta = float(beta)
+    def __init__(self, statistics: str, beta: float, poles: np.ndarray):
+        self._statistics = statistics
+        self._beta = beta
         self._poles = np.array(poles)
 
     @_util.ravel_argument(last_dim=True)
     def __call__(self, n):
         """Evaluate basis functions at given frequency n"""
         iv = 1j*n * np.pi/self._beta
-        return 1/(iv[None, :] - self._poles[:, None])
+        if self._statistics == 'F':
+            return 1 /(iv[None, :] - self._poles[:, None])
+        else:
+            return np.tanh(0.5 * self._beta * self._poles)[:, None]\
+                /(iv[None, :] - self._poles[:, None])
 
 
 class TauPoleBasis:
-    def __init__(self, beta: float, statistics: str, poles):
+    def __init__(self, statistics: str, beta: float, poles: np.ndarray):
         self._beta = beta
         self._statistics = statistics
         self._poles = np.array(poles)
@@ -39,11 +44,7 @@ class TauPoleBasis:
         y = self._poles/self._wmax
         lambda_ = self._beta * self._wmax
 
-        if self._statistics == "F":
-            res = -kernel.LogisticKernel(lambda_)(x[:, None], y[None, :])
-        else:
-            K = kernel.RegularizedBoseKernel(lambda_)
-            res = -K(x[:, None], y[None, :])/y[None, :]
+        res = -LogisticKernel(lambda_)(x[:, None], y[None, :])
         return res.T
 
 
@@ -55,18 +56,18 @@ class SparsePoleRepresentation:
     def __init__(self, basis: _basis.FiniteTempBasis, sampling_points=None):
         if sampling_points is None:
             sampling_points = basis.default_omega_sampling_points()
+        if not isinstance(basis.kernel, LogisticKernel):
+            raise ValueError("SPR supports only LogisticKernel")
 
         self._basis = basis
         self._poles = np.asarray(sampling_points)
         self._y_sampling_points = self._poles/basis.wmax
 
-        self.u = TauPoleBasis(basis.beta, basis.statistics, self._poles)
-        self.uhat = MatsubaraPoleBasis(basis.beta, self._poles)
+        self.u = TauPoleBasis(basis.statistics, basis.beta, self._poles)
+        self.uhat = MatsubaraPoleBasis(basis.statistics, basis.beta, self._poles)
 
         # Fitting matrix from IR
-        weight_func = basis.kernel.weight_func(self.statistics)
-        weight = weight_func(self._y_sampling_points)
-        F = -basis.s[:, None] * basis.v(self._poles) * weight[None, :]
+        F = -basis.s[:, None] * basis.v(self._poles)
 
         # Now, here we *know* that F is ill-conditioned in very particular way:
         # it is a product A * B * C, where B is well conditioned and A, C are
